#
# spec file for package lbdb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lbdb
Version:        0.52.1
Release:        1.4
Summary:        Address Database for mutt
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            https://www.spinnaker.de/lbdb/
Source:         https://www.spinnaker.de/lbdb/download/lbdb-%{version}.tar.gz
Patch0:         lbdb.rc.dif
Patch2:         lbdb-hostname.diff
Suggests:       perl(Getopt::Long)
Suggests:       perl(Net::LDAP)

%description
The Little Brother's Database (lbdb) consists of a set of small tools
that collect mail addresses from several sources and offer these
addresses to the external query feature of the Mutt mail reader.

To use the fetch address feature, put the following lines in your
.procmailrc:

:0hc | lbdb-fetchaddr

To use the database in mutt, put the following line into your .muttrc:

set query_command="lbdbq %{s}"

%prep
%autosetup -p1

%build
export \
  CFLAGS="%{optflags} -fno-strict-aliasing" \
  PGP="%{_bindir}/pgp" \
  PGPK="%{_bindir}/pgpk" \
  GPG="%{_bindir}/gpg" \
  FINGER="%{_bindir}/finger" \
  ABOOK="%{_bindir}/abook" \
  ADDR_EMAIL="%{_bindir}/addr-email" \
  SH="/bin/sh" \
  YPCAT="%{_bindir}/ypcat" \
  MAWK="%{_bindir}/awk"
%configure \
	--libdir=%{_libdir}/lbdb \
	--enable-lbdb-dotlock
%make_build

%install
mkdir -p %{buildroot}%{_sysconfdir}
make \
  prefix=%{buildroot}%{_prefix} \
  bindir=%{buildroot}%{_bindir} \
  sysconfdir=%{buildroot}%{_sysconfdir} \
  mandir=%{buildroot}%{_mandir} \
  libdir=%{buildroot}%{_libdir}/lbdb \
  install

%files
%license COPYING
%doc README.md TODO
%config(noreplace) %{_sysconfdir}/*
%{_bindir}/*
%{_libdir}/lbdb/
%{_mandir}/man?/*

%changelog
* Mon Jul 31 2023 Dirk Müller <dmueller@suse.com>
- update to 0.52.1:
  * Fix version information.
  * The m_inmail DB is now located by default in
  * $XDG_DATA_HOME/lbdb/m_inmail.db.  For backward compatibility
    an already existing $HOME/.lbdb/m_inmail.utf-8 file is used as
    first* preference
  * Add $XDG_CONFIG_HOME/lbdb/config as additional ldbdrc file
    location, and $XDG_CONFIG_HOME/lbdb/ldap.rc as additional
    ldaprc file location
  * lbdb-fetchaddr: discard stdin at the end to avoid problems
    with tee(1) and command substitution
* Wed Jun 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.51.1:
  * Add support for running testsuite on local built code (via $USE_LOCAL_LIB).
  * Add testsuite for m_inmail/lbdb-fetchaddr.
  * Fix example of MUNGE_LIMITDATE in lbdb.rc.
  * Ignore case and non alphanumeric chars in SORT_OUTPUT=name.
  * Update dotlock code from mutt 2.2.1 (uses snprintf now).
  * Update rfc822 code from mutt 2.2.1.
  * Fix quoting of grep Regex in m_muttalias.
  * Repair missing 7bit name part in rfc2047 on arm and mips architecture.
* Wed Nov 10 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.49.1:
  * Update to Standards-Version 4.6.0
  * Create empty config.rpath to make autoconf 2.71 happy
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.49
  * lbdbq: re-add $exec_prefix, which may be used in libdir.
  * Strip suffixes starting with "+" from elpa version.
  * Forward INMAIL_DB default from m_inmail to lbdb-munge.
  * Build-Depends on dh-elpa >= 1.16 to avoid path injection (Closes: #973971)
  * Upgrade to debhelper v13 and use debhelper-compat instead of d/compat.
  * Upgrade Standards-Version to 4.5.0.
  * Move mutt_ldap_query to /usr/bin, since it can be called separately.
  * Linitian override for false positive bin-sbin-mismatch.
* Wed May  6 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.48.1:
  * Fix wrong quoting in lbdb-fetchaddr
  * m_muttalias: Fix some shellcheck warnings.
  * Change project homepage URL to https.
  * Use literal tab characters in order to make m_abook and m_goobook
    modules work without requiring GNU sed(1).  Thanks to Raf Czlonka.
  * Add tests for m_abook.
  * Add update-version target to update version in all autotool files.
  * m_abook: Fix a shellcheck warning.
  * lbdbq, lbdb-fetchaddr: Fix some shellcheck warnings.
  * Upgrade Standards-Version to 4.3.0
  - Declare Rules-Requires-Root: no.
  * Upgrade debhelper to v12.
  * m_inmail/lbdb-munge: Use INMAIL_DB if set in config
  * Upgrade debhelper to v11.
  * Replace legacy `...` by $(...) in sh scripts.
  * Update copyright notice.
  * Add test_perl to check perl syntax.
  * Add some perl libs <!nocheck> to Build-Depends, to be able do
    perl syntax check.
  * Replace undefined $rv by $?.
  * Make the database file for m_inmail/lbdb-fetchaddr configurable.
  * Add LBDB_OVERRIDE_METHODS, OVERIDE_MUTTALIAS_FILES variables for
    testing.
  * Add a test suite.
  - Add a test for m_muttalias.
  * m_muttalias: rewrite sed regex as ERE, which should be more POSIX
    compatible and should work on non GNU sed, too.
  * lbdbq: Remove whitespace from number of matches to become more
    portable.
* Wed Dec  9 2015 mpluskal@suse.com
- Cleanup spec file
* Thu Jan 29 2015 p.drouand@gmail.com
- Update to version 0.39
  * Use dh_autotools-dev (Closes: bdo#727289).
  * Update packaged autotools files.
  * Rebuild aclocal/autoconf.
  * Change debian/source-format to 3.0 (native).
  * Remove mutt-ja from Suggests, since this no longer exists.
  * Upgrade build depenency to debhelper (>= 9).
  * Change debian/compat to "9".
  * Complete rewrite of debian/rules.
  * Now uses hardening via debhelper.
  * Add $CPPFLAGS to $CFLAGS to really use hardening.
  * Upgrade to Standards-Version 3.9.5 (no changes).
  * m_vcf: Optimize missing names handling (Closes: bdo#624590).
  * Made debian/copyright machine readable.
  * m_abook: fix formatting (Closes: bdo#681526).
  * mutt-ldap-query: Add parameters for TLS and SASL_MECH (Closes: bdo#512074).
  * Mention user mutt-ldap-query configuration files in lbdbq(1) man page
    (Closes: bdo#534710).
  * Update ABQuery build mechanism
- Remove obsolete AUTHORS section
- Remove redundant %%clean section
- Do not package INSTALL file into doc directory
* Thu Aug  1 2013 lnussel@suse.de
- new version 0.38
  * m_evolution: Try to evaluate the location of
    evolution-addressbook-export at runtime, since it is no longer
    available in /usr/bin since evolution 2.30.1.2-3
    (Closes: #583851, #598380).
  * m_vcf: Apply patch by Jamey Sharp <jamey@minilop.net> to support VCF
    contacts without real name (Closes: #624590).
  * vcquery: Apply patch by martin f krafft <madduck@debian.org> to search
    in NICKNAME field, too. (Closes: #586300).
- remove lbdb-0.32-evolution.diff
* Tue Feb  8 2011 lnussel@suse.de
- Suggest perl(Net::LDAP) (bnc#669969)
* Wed May 19 2010 lnussel@suse.de
- new version 0.37
  * Fix bashisms in m_bbdb
  * Fix query shell functions to catch non-zero exit status in case they
    get invoked in set -e context.
  * m_evolution: support line breaks and long lines.
  * Fix documentation concerning the quotes on lbdbq call
- fix path to evolution-addressbook-export
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Oct  2 2008 lnussel@suse.de
- new version 0.36
  * Remove duplicate "See also: mutt" from lbdbq.man.
  * Update configure using autconf 2.61.
  * Apply charset conversation patch by Peter Colberg based on code by
    Tobias Schlemmer.
  * Remove duplicate declaration of $ignorant.
  * Handle mail addresses in mutt_ldap_query correct. Thanks to Colin
    Watson <cjwatson@debian.org> for providing a patch.
  * Mention ldapi URIs in mutt_ldap_query man page.
  * Protect "make distclean" by checking whether makefile exists.
  * Upgrade to Standards-Version 3.8.0:
  - Fix Homepage header in control file.
  * Add copyright holders to debian/copyright file.
  * Remove outdated override.Lintian.
* Fri Aug 10 2007 lnussel@suse.de
- new version 0.35.1
  * supports ldaps
* Wed May 16 2007 lnussel@suse.de
- new version 0.34
  * vcquery: avoid free() on unallocated memory if fullname is not set.
  * vcquery: Use value of concatenated N fields if FN field is missing.
- fix hostname lookup if multiple domains are listed in resolv.conf
* Mon Oct 16 2006 lnussel@suse.de
- new version 0.33
  * Add SORT_OUTPUT=reverse_comment to do reverse sort by the third column
    (most recent m_inmail timestamp at the top).
  * Comment out LDAP_NICKS in lbdb.rc because this should only be an
    example and if it is set there it overrides other LDAP settings
* Thu Aug 24 2006 lnussel@suse.de
- new version 0.32
- fix path to evolution-addressbook-export
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon May  9 2005 lnussel@suse.de
- update to version 0.30
* Fri Feb 27 2004 lnussel@suse.de
- run configure similar to the original debian package to reduce
  neededforbuild and to fix evolution addressbook query
- add gpg to default address query methods
* Thu Feb 26 2004 lnussel@suse.de
- update to version 0.29
* Sun Feb  8 2004 lnussel@suse.de
- update to version 0.28.2
- use %%optflags, fix aliasing problems
* Wed Feb 12 2003 lnussel@suse.de
- new version 0.26.2
  * new ldap option $ignorant
  * support for multiple abook address books
* Fri Aug 16 2002 ro@suse.de
- removed emtpy post/postun scripts (#17916)
* Thu Apr 25 2002 lnussel@suse.de
- new version 0.26
- now uses m_getent instead of m_passwd (lbdb.rc.dif)
- moved files from %%{_prefix}/lib to %%{_libdir}/lbdb
* Tue Jul 24 2001 lnussel@suse.de
- new version 0.25
* Tue Mar 20 2001 lnussel@suse.de
- new version 0.24
- added finger to neededforbuild
* Wed Feb  7 2001 lnussel@suse.de
- new version 0.23
- neededforbuild: ypbind -> yp-tools
* Thu Nov 30 2000 ro@suse.de
- neededforbuild: ypclient -> ypbind
* Thu Oct 12 2000 lnussel@suse.de
- new version 0.21.1
- cleaned up spec file
- changed Group to Applications/Mail
* Tue Aug 29 2000 lnussel@suse.de
- initial check in
